import {EventEmitter2} from 'eventemitter2';
import {Set} from 'immutable';
import {LocalMediaHandler} from '../media/LocalMediaHandler';
import {ManagedStream} from '../media/ManagedStream';
import {User} from '../session/User';
import {CallRemoteRecorder} from './CallRemoteRecorder';
import {CallDirection} from './CallDirection';
import {CallEndReason} from './CallEndReason';
import {CallStatus} from './CallStatus';


export class Call {
	emitter: EventEmitter2;

	/**
	 * Attempts to reach the call recipient and establish a connection.
	 */
	connect(): Promise<Call>;

	/**
	 * Create an object to manage the remote recording.
	 */
	createCallRecorder(type: string): CallRemoteRecorder;

	/**
	 * Disconnects or rejects the call.
	 */
	disconnect(): Promise<Call>;

	/**
	 * Returns actual call context.
	 */
	getContext(): object;

	/**
	 * Returns the direction of the call.
	 */
	getDirection(): CallDirection;

	/**
	 * Returns the end reason of the call.
	 */
	getEndReason(): CallEndReason;

	getId(): string;

	/**
	 * Returns a set containing the local only streams.
	 */
	getLocalOnlyStreams(): Set<ManagedStream>;

	/**
	 * Return the media constraints configured for the call.
	 */
	getMediaConstraints(): MediaStreamConstraints;

	/**
	 * Returns a the remote gateway user.
	 */
	getRemoteGatewayUser(): string;

	/**
	 * Returns a set containing the remote streams.
	 */
	getRemoteStreams(): Set<ManagedStream>;

	/**
	 * Returns a user object representing the remote user if exists.
	 */
	getRemoteUser(): User;

	/**
	 * Returns the current status of the call.
	 */
	getStatus(): CallStatus;

	/**
	 * Returns a boolean value indicating if the call has a local only video
	 * track.
	 */
	hasLocalOnlyVideo(): boolean;

	/**
	 * Returns a boolean value indicating if the call has a remote audio track.
	 */
	hasRemoteAudio(): boolean;

	/**
	 * Returns a boolean value indicating if the call has a remote video track.
	 */
	hasRemoteVideo(): boolean;

	/**
	 * Returns true if Call is in any of the specified status.
	 */
	hasStatus(...args: CallStatus[]): boolean;

	/**
	 * Holds this call.
	 */
	hold(): Promise<void>;

	/**
	 * Returns true if the Call is polling.
	 */
	isPolling(): boolean;

	/**
	 * Resumes this call.
	 */
	resume(): Promise<void>;

	/**
	 * Send a DTMF tone.
	 */
	sendDtmf(key: string): void;

	/**
	 * Set some optional data that will be sent when creating the call.
	 */
	setContext(context: object): Call;

	transfer(to: string): Promise<boolean>;

	/**
	 * Allows access to local streams and actions related to changing which local media is shared
	 */
	getLocalMediaHandler(): LocalMediaHandler;

	/**
	 * Returns a promise that is resolved when the call changes to the requested
	 * status.
	 */
	waitForStatus(...statusList: CallStatus[]): Promise<CallStatus>;
}
