import EventEmitter from 'eventemitter3';
import { MediaTypes } from '../types';
import { ManagedStream } from './ManagedStream';
declare type UpdateMedia = (audio: MediaStreamConstraints['audio'], video: MediaStreamConstraints['video'], screen: boolean) => Promise<void>;
interface Events {
    videoStream: [];
    '*': [];
}
/**
 * Provides access to methods for managing actions related to local media. Instances of this class
 * are obtained calling {@link Call#getLocalMediaHandler} or {@link Conference#getLocalMediaHandler}
 *
 * ## Events
 *
 * - `videoStream` - Emitted every time videoStream changes.
 * - `*` - Emitted every time a change that can affect to any property happens.
 */
export declare class LocalMediaHandler {
    readonly emitter: EventEmitter<Events>;
    private _mediaTypes;
    private _mediaConstraints;
    private _updateMedia;
    private _videoStream?;
    private _audioOnlyStream?;
    private _availableAudioInputDevices;
    private _availableAudioOutputDevices;
    private _availableVideoInputDevices;
    private _activeAudioInputDevice?;
    private _activeVideoInputDevice?;
    private _audioMuted;
    private _videoMuted;
    private _beforeShareScreenVideo;
    /** @ignore */
    constructor(mediaConstraints: MediaStreamConstraints | undefined, updateMedia: UpdateMedia);
    /**
     * Return the media types configured for the call
     * @return {MediaTypes}
     */
    getMediaTypes(): MediaTypes;
    /**
     * Update the enabled local media. This feature is only available
     * when the call has already been connected if "media-update" capability is present.
     * @param {MediaTypes} mediaTypes The requested media
     * @return {Promise<undefined>}
     *
     * @example <caption>Disable video</caption>
     * await call.setMediaTypes({audio: true, video: false, screen: false});
     * console.log("media updated");
     */
    setMediaTypes(mediaTypes: MediaTypes): Promise<void>;
    /**
     * Return the media constraints configured for the call
     * @return {MediaStreamConstraints}
     */
    getMediaConstraints(): MediaStreamConstraints;
    /**
     * Update constraints of local media. This feature is only available when the call
     * has already been connected if "media-update" capability is present.
     * @param {MediaStreamConstraints} mediaConstraints The requested media constraints
     * @return {Promise<undefined>}
     *
     * @example <caption>Change video resolution</caption>
     * const audio = true;
     * const video = {
     *   height: 256,
     *   width: 256,
     * };
     * await call.setMediaConstraints({audio, video});
     * console.log("media updated");
     */
    setMediaConstraints(mediaConstraints: MediaStreamConstraints): Promise<void>;
    /**
     * Obtains current enabled media stream constraints.
     * This is a combination of the media stream constraints configured
     * for the call and the current media types.
     * @param {{mediaTypes: ?MediaTypes, mediaConstraints: ?MediaStreamConstraints}} param
     * @return {MediaStreamConstraints}
     */
    getCurrentMediaConstraints({ mediaTypes, mediaConstraints, }?: {
        mediaTypes?: MediaTypes | undefined;
        mediaConstraints?: MediaStreamConstraints | undefined;
    }): MediaStreamConstraints;
    /**
     * Returns the local video stream
     * @return {ManagedStream|undefined}
     */
    getVideoStream(): ManagedStream | undefined;
    /** @ignore */
    setVideoStream(stream?: MediaStream): void;
    /** @ignore */
    setAudioOnlyStream(stream?: MediaStream): void;
    /**
     * Returns a boolean value indicating if the call has a local audio track
     * @return {boolean}
     */
    hasAudioTrack(): boolean;
    /**
     * Returns a boolean value indicating if the call has a local video track
     * @return {boolean}
     */
    hasVideoTrack(): boolean;
    /**
     * Returns a boolean value indicating if local audio is muted
     * @return {boolean}
     */
    isAudioMuted(): boolean;
    /**
     * Mutes or unmutes the audio. If no parameter is specified it toggles current value.
     * @param {boolean} [mute] If specified forces audio to be mute or unmute
     */
    muteAudio(mute?: boolean): void;
    /**
     * Returns a boolean value indication if local video is muted
     * @return {boolean}
     */
    isVideoMuted(): boolean;
    /**
     * Mutes or unmutes the video. If no parameter is specified it toggles current value.
     *
     * Note that this method just turns the emitted video black and implies no media renegotiation.
     * Therefore, a video track will continue to be streamed. If you are instead looking for a method
     * to stop sending video altogether check {@link LocalMediaHandler.toggleVideo}.
     * @param {boolean} [mute] When specified forces video to be mute or unmute
     */
    muteVideo(mute?: boolean): void;
    /**
     * Indicates if video can be enabled or disabled
     * @return {boolean}
     */
    canToggleVideo(): boolean;
    /**
     * Enables or disables the video. If no parameter is specified it toggles current value.
     *
     * Note that this method will imply a media renegotation because the video track will be
     * added or removed from the RTCPeerConnection. As a consequence, remote participants
     * will receive a change in their remote participants streams.
     * @param {boolean} [video] If specified forces video to be enabled or not
     * @return {Promise<undefined>}
     */
    toggleVideo(video?: boolean): Promise<void>;
    /**
     * Shares the screen. This feature is only available if "screen-sharing" capability is present.
     * @param {boolean} [screen] send screen if true, camera if false.
     * If not specified it toggles from the last state.
     * @return {Promise<undefined>}
     */
    toggleScreen(screen?: boolean): Promise<void>;
    /**
     * Updates media types adding video when screen is false or adds an internal mark to know video must be
     * enabled when screen sharing ends.
     * @return {Promise<undefined>}
     */
    addVideo(): Promise<void>;
    /**
     * Returns the list of available audio input devices
     * @return {MediaDeviceInfo[]} A list of MediaDeviceInfo objects that can be used as audio input
     */
    getAvailableAudioInputDevices(): MediaDeviceInfo[];
    /**
     * Replaces the list of available audio input devices
     * @param {MediaDeviceInfo[]} availableAudioInputDevices The list of MediaDeviceInfo objects to be used as audio input
     * @return {Promise<undefined>}
     */
    setAvailableAudioInputDevices(availableAudioInputDevices: MediaDeviceInfo[]): Promise<void>;
    /**
     * Updates the audio input device in used to the specified one
     * @param {MediaDeviceInfo} [audioInputDevice] If no value is specified the default one is selected
     * @return {Promise<undefined>}
     */
    setActiveAudioInputDevice(audioInputDevice?: MediaDeviceInfo): Promise<void>;
    /**
     * Returns the list of available video input devices
     * @return {MediaDeviceInfo[]} A list of MediaDeviceInfo objects that can be used as video input
     */
    getAvailableVideoInputDevices(): MediaDeviceInfo[];
    /**
     * Replaces the list of available video input devices
     * @param {MediaDeviceInfo[]} availableVideoInputDevices
     * The list of MediaDeviceInfo objects to be used as audio input
     * @return {Promise<undefined>}
     */
    setAvailableVideoInputDevices(availableVideoInputDevices: MediaDeviceInfo[]): Promise<void>;
    /**
     * Updates the video input device in used to the specified one
     * @param {MediaDeviceInfo} [videoInputDevice] If no value is specified the default one is selected
     * @return {Promise<undefined>}
     */
    setActiveVideoInputDevice(videoInputDevice?: MediaDeviceInfo): Promise<void>;
    /**
     * Returns the list of available audio output devices
     * @return {MediaDeviceInfo[]} A list of MediaDeviceInfo objects that can be used as audio output
     */
    getAvailableAudioOutputDevices(): MediaDeviceInfo[];
    /**
     * Indicates if it is possible to change to a different camera
     * @return {boolean}
     */
    canToggleCamera(): boolean;
    /**
     * Changes the local video stream to the next available camera.
     * @return {Promise<undefined>}
     */
    toggleCamera(): Promise<void>;
    /** @ignore */
    init(): Promise<void>;
    /**
     * Force the update of the devices list
     */
    forceUpdateDevices(): Promise<void>;
    /**
     * Return the MediaDeviceInfo of the active audio device
     * @returns MediaDeviceInfo
     */
    getActiveAudioDevice(): MediaDeviceInfo | undefined;
    /**
     * Return the MediaDeviceInfo of the active video device
     * @returns MediaDeviceInfo
     */
    getActiveVideoDevice(): MediaDeviceInfo | undefined;
    /** @private */
    private getActiveVideoInputDeviceFromLocalStreams;
    /** @private */
    private getNextVideoInputDevice;
}
export {};
